@@ -1,7 +1,7 @@
 package App::MediaInfo;
 
 our $DATE = '2019-06-09'; # DATE
-our $VERSION = '0.122'; # VERSION
+our $VERSION = '0.123'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,7 +12,8 @@ our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'Utilities related to media files',
+    summary => 'Utilities related to getting (metadata) information from '.
+        'media files',
 };
 
 our %arg0_media_multiple = (
@@ -217,7 +218,7 @@ sub media_orientation {
 }
 
 1;
-# ABSTRACT: Utilities related to media files
+# ABSTRACT: Utilities related to getting (metadata) information from media files
 
 __END__
 
@@ -227,11 +228,11 @@ __END__
 
 =head1 NAME
 
-App::MediaInfo - Utilities related to media files
+App::MediaInfo - Utilities related to getting (metadata) information from media files
 
 =head1 VERSION
 
-This document describes version 0.122 of App::MediaInfo (from Perl distribution App-MediaInfo), released on 2019-06-09.
+This document describes version 0.123 of App::MediaInfo (from Perl distribution App-MediaInfo), released on 2019-06-09.
 
 =head1 FUNCTIONS
 
